Page 120 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 120

Home

    tons of gas bombs and incendiary grenades on the
    freedom fighters. The only things the United States
    government showed any interest in protecting were the
    antireligious dictators and American oil, mineral, and
    banking interests.

    Efforts to take the story of the plight of Mexico to the
    American press were effectively blocked by a censorship
    of silence. When a famous international reporter went to
    Mexico and wrote an authentic account of the events

    taking place, no large North American newspaper would
    print it. The New York Daily wanted the story, but the
    millionaire owner forbid the editor to touch it. By this
    time (1928), the Money Barons in New York had
    purchased control of the major newspapers in the United
    States and Mr. McCullagh had to go to England to find

    a publisher.
    Although the Socialist rulers of Mexico spent millions

    of dollars on propaganda in U. S. newspapers, the truth
    did eventually begin to filter through. Much of the credit
    for the circumventing of the censorship was due to the
    efforts of the Knights of Columbus. As a result, protests
    from across America began to flow into Congress, the
    Senate, and the State Department. This resulted in a
    resolution of Congress (the Borah Resolution) calling for
    a Congressional investigation into the matter.
    Resolutions were also passed by six state legislatures
    supporting the Borah Resolution. Protestant, Catholic,
    and Jewish leaders also supported it.

    into

    matter.

    115

    Babylon's War Against God